<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

  <xsl:template match="harndata">
    <chars>
      <xsl:apply-templates select="character"/>
    </chars>
  </xsl:template>

  <xsl:template match="character">
    <xsl:element name="char">
      <xsl:attribute name="name">
        <xsl:value-of select="//name"/>
      </xsl:attribute>
      <xsl:apply-templates select="species"/>
      <xsl:apply-templates select="gender"/>
      <xsl:apply-templates select="socialclass"/>
      <xsl:apply-templates select="deity"/>
      <xsl:apply-templates select="occupation"/>
      <xsl:apply-templates select="birthdate"/>
      <xsl:apply-templates select="birthplace"/>
      <xsl:apply-templates select="appearance"/>
      <xsl:apply-templates select="clan"/>
      <xsl:apply-templates select="parent"/>
      <xsl:apply-templates select="family"/>
      <xsl:apply-templates select="attribute"/>
      <xsl:apply-templates select="skill"/>
    </xsl:element>
  </xsl:template>

  <xsl:template match="species">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Species</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="gender">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Gender</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="socialclass">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Social Class</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="deity">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Deity</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="occupation">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Own Occupation</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="birthdate">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Birthdate</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@day"/>
        <xsl:text>-</xsl:text>
        <xsl:choose>
          <xsl:when test="@month=1">Nuz</xsl:when>
          <xsl:when test="@month=2">Peo</xsl:when>
          <xsl:when test="@month=3">Kel</xsl:when>
          <xsl:when test="@month=4">Nol</xsl:when>
          <xsl:when test="@month=5">Lar</xsl:when>
          <xsl:when test="@month=6">Agr</xsl:when>
          <xsl:when test="@month=7">Azu</xsl:when>
          <xsl:when test="@month=8">Hal</xsl:when>
          <xsl:when test="@month=9">Sav</xsl:when>
          <xsl:when test="@month=10">Ilv</xsl:when>
          <xsl:when test="@month=11">Nav</xsl:when>
          <xsl:when test="@month=12">Mor</xsl:when>
        </xsl:choose>
        <xsl:text>-</xsl:text>
        <xsl:value-of select="@year"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="birthplace">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Birthplace</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@kingdom"/>
        <xsl:text>/</xsl:text>
        <xsl:value-of select="@settlement"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="appearance">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Complexion</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@complexion"/>
      </xsl:attribute>
    </xsl:element>
    <xsl:element name="attribute">
      <xsl:attribute name="name">Eye Color</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@eyecolor"/>
      </xsl:attribute>
    </xsl:element>
    <xsl:element name="attribute">
      <xsl:attribute name="name">Hair Color</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@haircolor"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="clan">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Clanhead</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@clanhead"/>
      </xsl:attribute>
    </xsl:element>
    <xsl:element name="attribute">
      <xsl:attribute name="name">Estrangement</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@estrangement"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="parent">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Parent Occupation</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@occupation"/>
      </xsl:attribute>
    </xsl:element>
    <xsl:element name="attribute">
      <xsl:attribute name="name">Parent</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="."/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="family">
    <xsl:element name="attribute">
      <xsl:attribute name="name">Sibling Rank</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:choose>
          <xsl:when test="@rank=1">Eldest</xsl:when>
          <xsl:when test="@rank=2">2nd Child</xsl:when>
          <xsl:when test="@rank=3">3rd Child</xsl:when>
          <xsl:when test="@rank=4">4th Child</xsl:when>
          <xsl:when test="@rank=5">5th Child</xsl:when>
          <xsl:when test="@rank=6">6th Child</xsl:when>
        </xsl:choose>
      </xsl:attribute>
    </xsl:element>
    <xsl:element name="attribute">
      <xsl:attribute name="name">Family Size</xsl:attribute>
      <xsl:attribute name="value">
        <xsl:value-of select="@size"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="attribute">
    <xsl:element name="attribute">
      <xsl:attribute name="name">
        <xsl:choose>
          <xsl:when test=".='AGL'">Agility</xsl:when>
          <xsl:when test=".='AUR'">Aura</xsl:when>
          <xsl:when test=".='CML'">Comeliness</xsl:when>
          <xsl:when test=".='DEX'">Dexterity</xsl:when>
          <xsl:when test=".='EYE'">Eyesight</xsl:when>
          <xsl:when test=".='FRM'">Frame</xsl:when>
          <xsl:when test=".='HGT'">Height</xsl:when>
          <xsl:when test=".='HRG'">Hearing</xsl:when>
          <xsl:when test=".='INT'">Intelligence</xsl:when>
          <xsl:when test=".='MOR'">Morality</xsl:when>
          <xsl:when test=".='PIE'">Piety</xsl:when>
          <xsl:when test=".='SML'">Smell</xsl:when>
          <xsl:when test=".='STA'">Stamina</xsl:when>
          <xsl:when test=".='STR'">Strength</xsl:when>
          <xsl:when test=".='VOI'">Voice</xsl:when>
          <xsl:when test=".='WGT'">Weight</xsl:when>
          <xsl:when test=".='WIL'">Will</xsl:when>
        </xsl:choose>
      </xsl:attribute>
      <xsl:attribute name="value">
        <xsl:choose>
          <xsl:when test=".='FRM' and @value &lt; 6">Scant</xsl:when>
          <xsl:when test=".='FRM' and @value &gt; 5 and @value &lt; 9">Light</xsl:when>
          <xsl:when test=".='FRM' and @value &gt; 8 and @value &lt; 13">Medium</xsl:when>
          <xsl:when test=".='FRM' and @value &gt; 12 and @value &lt; 16">Heavy</xsl:when>
          <xsl:when test=".='FRM' and @value &gt; 15 and @value &lt; 19">Massive</xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="@value"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>

  <xsl:template match="skill">
    <xsl:element name="skill">
      <xsl:attribute name="name">
        <xsl:choose>
          <xsl:when test="contains(.,'Musician')">
            <xsl:text>Musician/</xsl:text>
            <xsl:value-of select="substring(.,11)"/>
          </xsl:when>
          <xsl:when test="contains(.,'Script')">
            <xsl:text>Script/</xsl:text>
            <xsl:value-of select="substring(.,9)"/>
          </xsl:when>
          <xsl:when test="contains(.,'Ritual')">
            <xsl:text>Ritual/</xsl:text>
            <xsl:value-of select="substring(.,9)"/>
          </xsl:when>
          <xsl:when test="contains(.,'Convocation')">
            <xsl:value-of select="substring(.,14)"/>
          </xsl:when>
          <xsl:when test="contains(.,'Language')">
            <xsl:choose>
              <xsl:when test=".='Language: Harnic'">Language/Jarind/Hârnic</xsl:when>
              <xsl:when test=".='Language: Altish'">Language/Jarind/Altish</xsl:when>
              <xsl:when test=".='Language: Emela'">Language/Jarind/Emela</xsl:when>
              <xsl:when test=".='Language: Jarinese'">Language/Jarind/Jarinese</xsl:when>
              <xsl:when test=".='Language: Old Jarinese'">Language/Jarind/Old Jarinese</xsl:when>
              <xsl:when test=".='Language: Orbaalese'">Language/Jarind/Orbaalese</xsl:when>
              <xsl:when test=".='Language: Yarili'">Language/Jarind/Yarili</xsl:when>
              <xsl:when test=".='Language: Harbaalese'">Language/Pharic/Harbaalese</xsl:when>
              <xsl:when test=".='Language: Ivinian'">Language/Pharic/Ivinian</xsl:when>
              <xsl:when test=".='Language: Palithanian'">Language/Pharic/Palithanian</xsl:when>
              <xsl:when test=".='Language: Quarph'">Language/Pharic/Quarph</xsl:when>
              <xsl:when test=".='Language: Trierzi'">Language/Pharic/Trierzi</xsl:when>
              <xsl:when test=".='Language: Shorka'">Language/Pharic/Shorka</xsl:when>
              <xsl:when test=".='Language: Azeri'">Language/Azeri/Azeri</xsl:when>
              <xsl:when test=".='Language: Azeryani'">Language/Azeri/Azeryani</xsl:when>
              <xsl:when test=".='Language: High Azeryani'">Language/Azeri/High Azeryani</xsl:when>
              <xsl:when test=".='Language: Low Azeryani'">Language/Azeri/Low Azeryani</xsl:when>
              <xsl:when test=".='Language: Urmech'">Language/Azeri/Urmech</xsl:when>
              <xsl:when test=".='Language: Karejian'">Language/Azeri/Karejian</xsl:when>
              <xsl:when test=".='Language: Byrian'">Language/Azeri/Byrian</xsl:when>
              <xsl:when test=".='Language: Besha'">Language/Ketar/Besha</xsl:when>
              <xsl:when test=".='Language: Karuia'">Language/Azeri/Karuia</xsl:when>
              <xsl:otherwise>
                <xsl:value-of select="substring(.,11)"/>
              </xsl:otherwise>
            </xsl:choose>
          </xsl:when>
          <xsl:when test=".='Axe' or .='Blowgun' or .='Bow' or .='Club' or .='Dagger' or .='Flail' or .='Net' or .='Polearm' or .='Shield' or .='Sling' or .='Spear' or .='Sword' or .='Whip'">
            <xsl:text>Weapon/</xsl:text>
            <xsl:value-of select="."/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="."/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
      <xsl:attribute name="sb">
        <xsl:value-of select="@oml"/>
      </xsl:attribute>
      <xsl:attribute name="sbadd">
        <xsl:value-of select="@op"/>
      </xsl:attribute>
      <xsl:attribute name="add">
        <xsl:value-of select="@sd"/>
      </xsl:attribute>
    </xsl:element>
  </xsl:template>
</xsl:stylesheet>
